#!/bin/sh

SKIP_XKB_PATCH=0
SKIP_XKEYSYM_PATCH=0
SKIP_LIBC5=0
OLDLIBS_DIR=""

echo "Checking configuration..."
if [ ! `whoami` = root ]
then
	echo "Sorry `whoami`, you must be root to perform this installation"
	exit 1
fi

if ! ls /lib/libc-2.0.* > /dev/null 2>&1
then
	echo "You don't seem to have glibc 2.0.x installed - is this a glibc-based system ?"
	exit 1
fi

if [ ! -f /usr/share/locale/locale.alias ]
then
	echo "You don't have any locale installed"
	exit 1
fi

if [ -f /usr/X11R6/lib/X11/xkb/symbols/czsk ]
then
	echo "The CZ and SK keymaps appear to be installed on this system."
	echo "Skiping them - please, check this and eventually apply XKB-patch manually"
	echo ""
	SKIP_XKB_PATCH=1
fi

if grep il2_ /usr/X11R6/lib/X11/XKeysymDB > /dev/null 2>&1
then
	echo "The keysym patch appears to be installed on this system."
	echo "Skipping it - please, check this and eventually apply XKeysymDB-patch manually"
	echo ""
	SKIP_XKEYSYM_PATCH=1
fi

if ls /usr/i486-linuxlibc5/lib/libX11.so.6.1 > /dev/null 2>&1
then
	OLDLIBS_DIR=/usr/i486-linuxlibc5/lib
elif ls /usr/i486-linux-libc5/lib/libX11.so.6.1 > /dev/null 2>&1
then
	OLDLIBS_DIR=/usr/i486-linux-libc5/lib
else
	echo "I have not found your old (libc5) X libraries."
	echo "Skipping installation of old library - check this and eventually copy manually"
	SKIP_LIBC5=1
fi


if ! locale -a | grep ^cs$ > /dev/null 2>&1
then
	if [ ! -d /usr/share/locale/cs_CZ ]
	then
		echo "Installing czech locale (sorry, don't have slovak one)..."
		cat cs_CZ.tar.gz | ( cd /usr/share/locale; tar xfz - )
		echo Done.
	fi

	if [ ! -e /usr/share/locale/cs ]
	then
		echo "Linking cs locale to cs_CZ one..."
		( cd /usr/share/locale ; ln -s cs_CZ cs )
		echo Done.
	fi
fi

if ! locale -a | grep ^cs$ > /dev/null 2>&1
then
	echo "Installation of czech and slovak locales failed - check manually"
fi

if [ $SKIP_XKB_PATCH = 0 ]
then
	echo "Installing and patching XKB files..."
	if cat XKB-patch |(cd /usr/X11R6/lib/X11 && patch -p0 -E -s )
	then
		echo Done.
	else
		echo "Something is wrong -- patch failed. Is XKB installed here?"
	fi
fi

if [ $SKIP_XKEYSYM_PATCH = 0 ]
then
	echo "Patching XKeysymDB file..."
	if cat XKeysymDB-patch |(cd /usr/X11R6/lib/X11 && patch -p0 -E -s )
	then
		echo Done.
	else
		echo "Something is wrong -- patch failed."
	fi
fi

echo "Installing patched libX11 (glibc version)..." 
cp -pf libX11-glibc.so.6.99 /usr/X11R6/lib/libX11.so.6.99
echo Done.

if [ $SKIP_LIBC5 = 0 ]
then
	echo "Installing patched libX11 (libc5 version)..."
	cp -pf libX11-libc5.so.6.99 $OLDLIBS_DIR/libX11.so.6.99
	echo Done.
fi

echo "Rebuilding dynamic linker data..."
ldconfig
echo Done.

cat <<EOF
*****************************************************************
*****************************************************************
Installation was successful.
Remember to comment out all the *Alt, *Ctl and ScrollLock options
in XF86Config's "Keyboard" section, and add the following line to
the XF86Config:

	XkbKeymap "xfree86(<map_name>)"

where <map_name> is one of the following:

	us_cz_qwerty
	us_cz_qwertz
	us_cz_prog
	cz_us_qwerty
	cz_us_qwertz
	cz_us_prog

	us_sk_qwerty
	us_sk_qwertz
	us_sk_prog
	sk_us_qwerty
	sk_us_qwertz
	sk_us_prog

Do not forget to set LANG (or at least LC_CTYPE) environment variable
to "cs" by the "export LANG=cs" in Bash or "setenv LANG=cs" in the
C-shell. CAUTION: this can break some Tk programs - unset the variable
before using such buggy program.

The on-the-fly internationalisation of dumb programs can be switched
by setting the XLIB_FORCE_I18N environment variable.

Unset any _XKB* variables as _XKB_CHARSET (used by some previous patches).

Installation finished.
EOF
exit 0
